==> sources_spiffyhud_fabric_3.1.0_MC_1.21.1.jar: de/keksuccino/spiffyhud/customization/elements/vanillalike/jumpmeter/VanillaLikeJumpMeterElement.java <==
package de.keksuccino.spiffyhud.customization.elements.vanillalike.jumpmeter;

import com.mojang.blaze3d.systems.RenderSystem;
import de.keksuccino.fancymenu.customization.element.AbstractElement;
import de.keksuccino.fancymenu.customization.element.ElementBuilder;
import de.keksuccino.fancymenu.util.rendering.RenderingUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.jetbrains.annotations.NotNull;
import java.util.Objects;
import net.minecraft.class_1316;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_332;

public class VanillaLikeJumpMeterElement extends AbstractElement {

    private static final Logger LOGGER = LogManager.getLogger();

    // Sprite resources for jump meter in 1.21.1
    private static final class_2960 JUMP_BAR_BACKGROUND_SPRITE = class_2960.method_60656("hud/jump_bar_background");
    private static final class_2960 JUMP_BAR_COOLDOWN_SPRITE = class_2960.method_60656("hud/jump_bar_cooldown");
    private static final class_2960 JUMP_BAR_PROGRESS_SPRITE = class_2960.method_60656("hud/jump_bar_progress");

    private static final int BAR_WIDTH = 182;
    private static final int BAR_HEIGHT = 5;

    private final class_310 minecraft = class_310.method_1551();

    public VanillaLikeJumpMeterElement(@NotNull ElementBuilder<?, ?> builder) {
        super(builder);
    }

    @Override
    public void method_25394(@NotNull class_332 graphics, int mouseX, int mouseY, float partial) {

        // Ensure that both the player and the level exist before rendering.
        if (this.minecraft.field_1724 == null || this.minecraft.field_1687 == null) return;

        // Retrieve the element's absolute position and size.
        int elementX = this.getAbsoluteX();
        int elementY = this.getAbsoluteY();
        int elementWidth = this.getAbsoluteWidth();
        int elementHeight = this.getAbsoluteHeight();

        // Enable blending and reset shader colors.
        RenderSystem.enableBlend();
        RenderingUtils.resetShaderColor(graphics);

        // Render the jump meter inside the element's bounds.
        this.renderJumpMeter(graphics, elementX, elementY, elementWidth, elementHeight);

        RenderingUtils.resetShaderColor(graphics);

    }

    /**
     * Renders the jump meter bar within the specified element bounds.
     *
     * @param graphics      The graphics context used for rendering.
     * @param elementX      The absolute x-coordinate of the element.
     * @param elementY      The absolute y-coordinate of the element.
     * @param elementWidth  The width of the element.
     * @param elementHeight The height of the element.
     */
    private void renderJumpMeter(class_332 graphics, int elementX, int elementY, int elementWidth, int elementHeight) {

        // Enable blending and set the shader color with the desired opacity.
        RenderSystem.enableBlend();
        graphics.method_51422(1.0f, 1.0f, 1.0f, this.opacity);

        // Get the player's rideable jump vehicle, if any.
        class_1316 rideable = Objects.requireNonNull(this.minecraft.field_1724).method_45773();

        // Calculate the jump riding scale and determine the width of the jump meter fill.
        float jumpScale = this.minecraft.field_1724.method_3151();
        int fillWidth = (int) (jumpScale * elementWidth);
        if (isEditor()) fillWidth = BAR_WIDTH / 2;

        // Draw the jump meter background
        graphics.method_52706(JUMP_BAR_BACKGROUND_SPRITE, elementX, elementY, elementWidth, elementHeight);

        // If the player is riding an entity with jump cooldown, render the cooldown overlay
        if ((rideable != null && rideable.method_45327() > 0) && !isEditor()) {
            graphics.method_52706(JUMP_BAR_COOLDOWN_SPRITE, elementX, elementY, elementWidth, elementHeight);
        }
        // Otherwise, if there is a jump meter fill value, render the filled portion
        else if (fillWidth > 0) {
            graphics.method_52708(JUMP_BAR_PROGRESS_SPRITE, elementWidth, elementHeight, 0, 0, elementX, elementY, fillWidth, elementHeight);
        }

        graphics.method_51422(1.0f, 1.0f, 1.0f, 1.0f);

    }

    @Override
    public int getAbsoluteWidth() {
        return BAR_WIDTH;
    }

    @Override
    public int getAbsoluteHeight() {
        return BAR_HEIGHT;
    }

}

==> sources_spiffyhud_fabric_3.1.1_MC_1.19.2.jar: de/keksuccino/spiffyhud/customization/elements/vanillalike/jumpmeter/VanillaLikeJumpMeterElement.java <==
package de.keksuccino.spiffyhud.customization.elements.vanillalike.jumpmeter;

import com.mojang.blaze3d.systems.RenderSystem;
import de.keksuccino.fancymenu.customization.element.AbstractElement;
import de.keksuccino.fancymenu.customization.element.ElementBuilder;
import de.keksuccino.fancymenu.util.rendering.RenderingUtils;
import de.keksuccino.fancymenu.util.rendering.gui.GuiGraphics;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.jetbrains.annotations.NotNull;
import java.util.Objects;
import net.minecraft.class_2960;
import net.minecraft.class_310;

public class VanillaLikeJumpMeterElement extends AbstractElement {

    private static final Logger LOGGER = LogManager.getLogger();

    // Texture containing GUI icons.
    private static final class_2960 GUI_ICONS_LOCATION = new class_2960("textures/gui/icons.png");

    private static final int BAR_WIDTH = 182;
    private static final int BAR_HEIGHT = 5;

    private final class_310 minecraft = class_310.method_1551();

    public VanillaLikeJumpMeterElement(@NotNull ElementBuilder<?, ?> builder) {
        super(builder);
    }

    @Override
    public void render(@NotNull GuiGraphics graphics, int mouseX, int mouseY, float partial) {

        // Ensure that both the player and the level exist before rendering.
        if (this.minecraft.field_1724 == null || this.minecraft.field_1687 == null) return;

        // Retrieve the element's absolute position and size.
        int elementX = this.getAbsoluteX();
        int elementY = this.getAbsoluteY();
        int elementWidth = this.getAbsoluteWidth();
        int elementHeight = this.getAbsoluteHeight();

        // Enable blending and reset shader colors.
        RenderSystem.enableBlend();
        RenderingUtils.resetShaderColor(graphics);

        // Render the jump meter inside the element's bounds.
        this.renderJumpMeter(graphics, elementX, elementY, elementWidth, elementHeight);

        RenderingUtils.resetShaderColor(graphics);

    }

    /**
     * Renders the jump meter bar within the specified element bounds.
     *
     * @param graphics      The graphics context used for rendering.
     * @param elementX      The absolute x-coordinate of the element.
     * @param elementY      The absolute y-coordinate of the element.
     * @param elementWidth  The width of the element.
     * @param elementHeight The height of the element.
     */
    private void renderJumpMeter(GuiGraphics graphics, int elementX, int elementY, int elementWidth, int elementHeight) {

        // Enable blending and set the shader color with the desired opacity.
        RenderSystem.enableBlend();
        graphics.setColor(1.0f, 1.0f, 1.0f, this.opacity);

        // Calculate the jump riding scale and determine the width of the jump meter fill.
        float jumpScale = this.minecraft.field_1724.method_3151();
        int fillWidth = (int) (jumpScale * elementWidth);
        if (isEditor()) fillWidth = BAR_WIDTH / 2;

        // Draw the jump meter background (texture region starting at y = 84).
        graphics.blit(GUI_ICONS_LOCATION, elementX, elementY, 0, 84, elementWidth, elementHeight);

        // If there is a jump meter fill value, render the filled portion (texture region at y = 89).
        if (fillWidth > 0) {
            graphics.blit(GUI_ICONS_LOCATION, elementX, elementY, 0, 89, fillWidth, elementHeight);
        }

        graphics.setColor(1.0f, 1.0f, 1.0f, 1.0f);

    }

    @Override
    public int getAbsoluteWidth() {
        return BAR_WIDTH;
    }

    @Override
    public int getAbsoluteHeight() {
        return BAR_HEIGHT;
    }

}
